@@ -1,6 +1,6 @@
 package Module::Build::Tiny;
 {
-  $Module::Build::Tiny::VERSION = '0.026';
+  $Module::Build::Tiny::VERSION = '0.027';
 }
 use strict;
 use warnings;
@@ -143,7 +143,7 @@ Module::Build::Tiny - A tiny replacement for Module::Build
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 SYNOPSIS
 
@@ -188,12 +188,14 @@ than 120, yet supports the features needed by most distributions.
 
 =item * Extending Module::Build::Tiny
 
+=item * Module sharedirs
+
 =back
 
 =head2 Directory structure
 
 Your .pm and .pod files must be in F<lib/>.  Any executables must be in
-F<script/>.  Test files must be in F<t/>.
+F<script/>.  Test files must be in F<t/>. Dist sharedirs must be in F<share/>.
 
 =head1 USAGE
 
@@ -211,6 +213,8 @@ This supports the following options:
 
 =over
 
+=item * verbose
+
 =item * install_base
 
 =item * installdirs
@@ -223,16 +227,35 @@ This supports the following options:
 
 =item * uninst
 
+=item * config
+
+=item * pure-perl
+
+=item * create_packlist
+
 =back
 
 =head1 AUTHORING
 
-This module doesn't support authoring. To develop modules using Module::Build::Tiny, usage of L<Dist::Zilla::Plugin::ModuleBuildTiny> is recommended.
+This module doesn't support authoring. To develop modules using Module::Build::Tiny, usage of L<Dist::Zilla::Plugin::ModuleBuildTiny> or L<App::ModuleBuildTiny> is recommended.
 
 =head1 CONFIG FILE AND ENVIRONMENT
 
-Options can be provided in a F<.modulebuildrc> file or in the C<PERL_MB_OPT>
-environment variable the same way they can with Module::Build.
+Options can be provided in the C<PERL_MB_OPT> environment variable the same way they can with Module::Build. This should be done during the configuration stage.
+
+=head2 Incompatibilities
+
+=over 4
+
+=item * Argument parsing
+
+Module::Build has an extremely permissive way of argument handling, Module::Build::Tiny only supports a (sane) subset of that. In particular, C<./Build destdir=/foo> does not work, you will need to pass it as C<./Build --destdir=/foo>.
+
+=item * .modulebuildrc
+
+Module::Build::Tiny does not support .modulebuildrc files. In particular, this means that versions of local::lib older than 1.006008 may break. Upgrading it resolves this issue.
+
+=back
 
 =head1 SEE ALSO
 
